ci

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

SPDX-License-Identifier: Apache-2.0

Copyright © 2023 The listen.dev team <engineering@garnet.ai>

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

SPDX-License-Identifier: Apache-2.0

Copyright © 2023 The listen.dev team <engineering@garnet.ai>

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsRunningInGitHubAction

func IsRunningInGitHubAction() bool

IsRunningInGitHubAction tells whether the current process is running in GitHub actions or not.

See https://docs.github.com/en/actions/learn-github-actions/variables#default-environment-variables.

Types

type GitHubEvent

type GitHubEvent struct {
	Repo        github.PushEventRepository `json:"repository"`
	HeadCommit  github.HeadCommit          `json:"head_commit"`
	PullRequest github.PullRequest         `json:"pull_request"`
	CheckSuite  github.CheckSuite          `json:"check_suite"`
}

func NewGitHubEventFromPath

func NewGitHubEventFromPath(eventPath string) (*GitHubEvent, error)

NewGitHubEventFromPath creates a GitHubEvent by reading the GITHUB_EVENT_PATH file.

type Info

type Info struct {
	Owner  string
	Repo   string
	SHA    string
	Num    int
	Branch string
}

func NewInfo

func NewInfo() (*Info, error)

NewInfo creates a Info from environment variables.

func NewInfoFromGitHubEvent

func NewInfoFromGitHubEvent() (*Info, error)

NewInfoFromGitHubEvent creates an Info instance using the the file on the GitHub action runner that contains the full event webhook payload.

See https://docs.github.com/en/actions/learn-github-actions/variables#default-environment-variables.

func (*Info) IsPullRequest

func (i *Info) IsPullRequest() bool

Jump to